@@ -9,9 +9,9 @@
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
+ *
  *   http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
@@ -28,11 +28,11 @@
 /**
  * Objects of this class store data about a single option for ezcConsoleInput.
  *
- * This class represents a single command line option, which can be handled by 
+ * This class represents a single command line option, which can be handled by
  * the ezcConsoleInput class. This classes only purpose is the storage of
  * the parameter data, the handling of options and arguments is done by the
  * class {@link ezcConsoleInput}.
- * 
+ *
  * @property-read string $short
  *                Short name of the parameter without '-' (eg. 'f').
  * @property-read string $long
@@ -50,7 +50,7 @@
  *           specified here.
  * @property bool $multiple
  *           Is the submission of multiple instances of this parameters
- *           allowed? 
+ *           allowed?
  * @property string $shorthelp
  *           Short help text. Usually displayed when showing parameter help
  *           overview.
@@ -59,7 +59,7 @@
  *           help.
  * @property bool $arguments
  *           Whether arguments to the program are allowed, when this parameter
- *           is submitted. 
+ *           is submitted.
  * @property bool $mandatory
  *           Whether a parameter is mandatory to be set.  If this flag is true,
  *           the parameter must be submitted whenever the program is run.
@@ -82,26 +82,26 @@ class ezcConsoleOption
 
     /**
      * Dependency rules of this parameter.
-     * 
+     *
      * @see ezcConsoleOption::addDependency()
      * @see ezcConsoleOption::removeDependency()
      * @see ezcConsoleOption::hasDependency()
      * @see ezcConsoleOption::getDependencies()
      * @see ezcConsoleOption::resetDependencies()
-     * 
+     *
      * @var array(string=>ezcConsoleParamemterRule)
      */
     protected $dependencies = array();
 
     /**
      * Exclusion rules of this parameter.
-     * 
+     *
      * @see ezcConsoleOption::addExclusion()
      * @see ezcConsoleOption::removeExclusion()
      * @see ezcConsoleOption::hasExclusion()
      * @see ezcConsoleOption::getExclusions()
      * @see ezcConsoleOption::resetExclusions()
-     * 
+     *
      * @var array(string=>ezcConsoleParamemterRule)
      */
     protected $exclusions = array();
@@ -111,7 +111,7 @@ class ezcConsoleOption
      * Boolean false indicates the parameter was not submitted, boolean
      * true means the parameter was submitted, but did not have a value.
      * In any other case, this caries the submitted value.
-     * 
+     *
      * @var mixed
      */
     public $value = false;
@@ -127,22 +127,22 @@ class ezcConsoleOption
      * </code>
      *
      * will result in a parameter that can be accessed using
-     * 
+     *
      * <code>
      * $ mytool -f
      * </code>
      *
      * or
-     * 
+     *
      * <code>
      * $ mytool --file
      * </code>
      * .
      *
-     * The newly created parameter contains only it's 2 names and each other 
+     * The newly created parameter contains only it's 2 names and each other
      * attribute is set to it's default value. You can simply manipulate
      * those attributes by accessing them directly.
-     * 
+     *
      * @param string $short      Short name of the parameter without '-' (eg. 'f').
      * @param string $long       Long name of the parameter without '--' (eg. 'file').
      * @param int $type          Value type of the parameter. One of ezcConsoleInput::TYPE_*.
@@ -154,24 +154,24 @@ class ezcConsoleOption
      * @param array(ezcConsoleOptionRule) $exclusions   Exclusion rules.
      * @param bool $arguments    Whether supplying arguments is allowed when this parameter is set.
      * @param bool $mandatory    Whether the parameter must be always submitted.
-     * @param bool $isHelpOption Indicates that the given parameter is a help 
-     *                           option. If a help option is set, all rule 
+     * @param bool $isHelpOption Indicates that the given parameter is a help
+     *                           option. If a help option is set, all rule
      *                           checking is skipped (dependency/exclusion/
      *                           mandatory).
      *
-     * @throws ezcConsoleInvalidOptionNameException If the option names start with a "-" 
+     * @throws ezcConsoleInvalidOptionNameException If the option names start with a "-"
      *                                              sign or contain whitespaces.
      */
-    public function __construct( 
-        $short = '', 
-        $long, 
-        $type = ezcConsoleInput::TYPE_NONE, 
-        $default = null, 
+    public function __construct(
+        $short = '',
+        $long = '',
+        $type = ezcConsoleInput::TYPE_NONE,
+        $default = null,
         $multiple = false,
         $shorthelp = 'No help available.',
-        $longhelp = 'Sorry, there is no help text available for this parameter.', 
+        $longhelp = 'Sorry, there is no help text available for this parameter.',
         array $dependencies = array(),
-        array $exclusions = array(), 
+        array $exclusions = array(),
         $arguments = true,
         $mandatory = false,
         $isHelpOption = false
@@ -186,25 +186,25 @@ class ezcConsoleOption
             throw new ezcConsoleInvalidOptionNameException( $short );
         }
         $this->properties['short'] = $short;
-        
+
         if ( !self::validateOptionName( $long ) )
         {
             throw new ezcConsoleInvalidOptionNameException( $long );
         }
         $this->properties['long'] = $long;
-        
+
         $this->__set( "type",      $type         !== null ? $type      : ezcConsoleInput::TYPE_NONE  );
         $this->__set( "multiple",  $multiple     !== null ? $multiple  : false  );
         $this->__set( "default",   $default      !== null ? $default   : null );
         $this->__set( "shorthelp", $shorthelp    !== null ? $shorthelp : 'No help available.' );
         $this->__set( "longhelp",  $longhelp     !== null ? $longhelp  : 'Sorry, there is no help text available for this parameter.' );
-        
+
         $dependencies    = $dependencies !== null && is_array( $dependencies ) ? $dependencies : array();
         foreach ( $dependencies as $dep )
         {
             $this->addDependency( $dep );
         }
-        
+
         $exclusions = $exclusions !== null && is_array( $exclusions ) ? $exclusions : array();
         foreach ( $exclusions as $exc )
         {
@@ -235,12 +235,12 @@ class ezcConsoleOption
         }
         $this->dependencies[] = $rule;
     }
-    
+
     /**
      * Remove a dependency rule from a parameter.
      * This removes a given rule from a parameter, if it exists. If the rule is
      * not registered with the parameter, the method call will simply be ignored.
-     * 
+     *
      * @param ezcConsoleOptionRule $rule The rule to be removed.
      * @return void
      */
@@ -254,13 +254,13 @@ class ezcConsoleOption
             }
         }
     }
-    
+
     /**
      * Remove all dependency rule referring to a parameter.
-     * This removes all dependency rules from a parameter, that refer to as specific 
-     * parameter. If no rule is registered with this parameter as reference, the 
+     * This removes all dependency rules from a parameter, that refer to as specific
+     * parameter. If no rule is registered with this parameter as reference, the
      * method call will simply be ignored.
-     * 
+     *
      * @param ezcConsoleOption $param The param to be check for rules.
      * @return void
      */
@@ -274,12 +274,12 @@ class ezcConsoleOption
             }
         }
     }
-    
+
     /**
      * Returns if a dependency to the given option exists.
      * Returns true if a dependency rule to the given option is registered,
      * otherwise false.
-     * 
+     *
      * @param ezcConsoleOption $param The param to check if a dependency exists to.
      * @return bool True if rule is registered, otherwise false.
      */
@@ -294,7 +294,7 @@ class ezcConsoleOption
         }
         return false;
     }
-    
+
     /**
      * Returns the dependency rules registered with this parameter.
      * Returns an array of registered dependencies.
@@ -307,7 +307,7 @@ class ezcConsoleOption
      *      2 => ezcConsoleOptionRule,
      * );
      * </code>
-     * 
+     *
      * @return array(ezcConsoleOptionRule) Dependency definition.
      */
     public function getDependencies()
@@ -318,10 +318,10 @@ class ezcConsoleOption
     /**
      * Reset existing dependency rules.
      * Deletes all registered dependency rules from the option definition.
-     * 
+     *
      * @return void
      */
-    public function resetDependencies() 
+    public function resetDependencies()
     {
         $this->dependencies = array();
     }
@@ -346,12 +346,12 @@ class ezcConsoleOption
         }
         $this->exclusions[] = $rule;
     }
-    
+
     /**
      * Remove a exclusion rule from a option.
      * This removes a given rule from a option, if it exists. If the rule is
      * not registered with the option, the method call will simply be ignored.
-     * 
+     *
      * @param ezcConsoleOptionRule $rule The rule to be removed.
      * @return void
      */
@@ -365,13 +365,13 @@ class ezcConsoleOption
             }
         }
     }
-    
+
     /**
      * Remove all exclusion rule referring to a option.
-     * This removes all exclusion rules from a option, that refer to as specific 
-     * option. If no rule is registered with this option as reference, the 
+     * This removes all exclusion rules from a option, that refer to as specific
+     * option. If no rule is registered with this option as reference, the
      * method call will simply be ignored.
-     * 
+     *
      * @param ezcConsoleOption $param The option to remove rule for.
      * @return void
      */
@@ -385,12 +385,12 @@ class ezcConsoleOption
             }
         }
     }
-    
+
     /**
      * Returns if a given exclusion rule is registered with the option.
      * Returns true if a exclusion rule to the given option is registered,
      * otherwise false.
-     * 
+     *
      * @param ezcConsoleOption $param The param to check if exclusions exist for.
      * @return bool True if rule is registered, otherwise false.
      */
@@ -405,7 +405,7 @@ class ezcConsoleOption
         }
         return false;
     }
-    
+
     /**
      * Returns the exclusion rules registered with this parameter.
      * Returns an array of registered exclusions.
@@ -418,7 +418,7 @@ class ezcConsoleOption
      *      2 => ezcConsoleOptionRule,
      * );
      * </code>
-     * 
+     *
      * @return array(ezcConsoleOptionRule) Exclusions definition.
      */
     public function getExclusions()
@@ -432,15 +432,15 @@ class ezcConsoleOption
      *
      * @return void
      */
-    public function resetExclusions() 
+    public function resetExclusions()
     {
         $this->exclusions = array();
     }
-    
+
     /**
      * Property read access.
      * Provides read access to the properties of the object.
-     * 
+     *
      * @param string $key The name of the property.
      * @return mixed The value if property exists and isset, otherwise null.
      * @ignore
@@ -468,13 +468,13 @@ class ezcConsoleOption
 
     /**
      * Property write access.
-     * 
+     *
      * @param string $key Name of the property.
      * @param mixed $val  The value for the property.
      *
      * @throws ezcBasePropertyPermissionException
      *         If the property you try to access is read-only.
-     * @throws ezcBasePropertyNotFoundException 
+     * @throws ezcBasePropertyNotFoundException
      *         If the the desired property is not found.
      * @ignore
      */
@@ -483,14 +483,14 @@ class ezcConsoleOption
         switch ( $key )
         {
             case 'type':
-                if ( $val !== ezcConsoleInput::TYPE_NONE 
-                     && $val !== ezcConsoleInput::TYPE_INT 
+                if ( $val !== ezcConsoleInput::TYPE_NONE
+                     && $val !== ezcConsoleInput::TYPE_INT
                      && $val !== ezcConsoleInput::TYPE_STRING )
                 {
-                    throw new ezcBaseValueException( 
-                        $key,  
-                        $val, 
-                        'ezcConsoleInput::TYPE_STRING, ezcConsoleInput::TYPE_INT or ezcConsoleInput::TYPE_NONE' 
+                    throw new ezcBaseValueException(
+                        $key,
+                        $val,
+                        'ezcConsoleInput::TYPE_STRING, ezcConsoleInput::TYPE_INT or ezcConsoleInput::TYPE_NONE'
                     );
                 }
                 break;
@@ -551,10 +551,10 @@ class ezcConsoleOption
         }
         $this->properties[$key] = $val;
     }
- 
+
     /**
      * Property isset access.
-     * 
+     *
      * @param string $key Name of the property.
      * @return bool True is the property is set, otherwise false.
      * @ignore
@@ -579,12 +579,12 @@ class ezcConsoleOption
     }
 
     /**
-     * Returns if a given name if valid for use as a parameter name a parameter. 
+     * Returns if a given name if valid for use as a parameter name a parameter.
      * Checks if a given parameter name is generally valid for use. It checks a)
      * that the name does not start with '-' or '--' and b) if it contains
      * whitespaces. Note, that this method does not check any conflicts with already
      * used parameter names.
-     * 
+     *
      * @param string $name The name to check.
      * @return bool True if the name is valid, otherwise false.
      */
