@@ -1,7 +1,7 @@
 <?php
 /**
  * ezcConsoleDialogTest class.
- * 
+ *
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -9,9 +9,9 @@
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
+ *
  *   http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
@@ -27,7 +27,7 @@
 
 /**
  * Generic test case for ezcConsoleDialog implementations.
- * 
+ *
  * @package ConsoleTools
  * @subpackage Tests
  */
@@ -47,7 +47,7 @@ abstract class ezcConsoleDialogTest extends ezcTestCase
 
     protected $res = array();
 
-    protected function setUp()
+    protected function setUp() : void
     {
         $this->dataDir = dirname( __FILE__ ) . DIRECTORY_SEPARATOR . "data" . DIRECTORY_SEPARATOR
             . ( ezcBaseFeatures::os() === 'Windows' ? "windows" : "posix" );
@@ -72,7 +72,7 @@ abstract class ezcConsoleDialogTest extends ezcTestCase
         }
     }
 
-    protected function tearDown()
+    protected function tearDown() : void
     {
         unset( $this->output );
     }
